pub struct BuiltInResourcesContainer { /* private fields */ }Expand description
A container for built-in resources. Every built-in resource is registered using its id defined at the creation stage.
Implementations
Sourceimpl BuiltInResourcesContainer
impl BuiltInResourcesContainer
Sourcepub fn add<T>(
&mut self,
resource: BuiltInResource<T>,
) -> Option<UntypedBuiltInResource>where
T: TypedResourceData,
pub fn add<T>(
&mut self,
resource: BuiltInResource<T>,
) -> Option<UntypedBuiltInResource>where
T: TypedResourceData,
Adds a new typed built-in resource and removes the previous one with the same id (if any).
Sourcepub fn add_untyped(
&mut self,
resource: UntypedBuiltInResource,
) -> Option<UntypedBuiltInResource>
pub fn add_untyped( &mut self, resource: UntypedBuiltInResource, ) -> Option<UntypedBuiltInResource>
Adds a new untyped built-in resource and removes the previous one with the same id (if any).
Sourcepub fn remove(&mut self, id: impl AsRef<Path>) -> Option<UntypedBuiltInResource>
pub fn remove(&mut self, id: impl AsRef<Path>) -> Option<UntypedBuiltInResource>
Tries to remove a built-in resource by its path.
Sourcepub fn find_by_uuid(&self, uuid: Uuid) -> Option<&UntypedBuiltInResource>
pub fn find_by_uuid(&self, uuid: Uuid) -> Option<&UntypedBuiltInResource>
Tries to find a built-in resource by its uuid.
Sourcepub fn is_built_in_resource_path(&self, resource: impl AsRef<Path>) -> bool
pub fn is_built_in_resource_path(&self, resource: impl AsRef<Path>) -> bool
Checks whether the given resource path corresponds to a built-in resource or not.
Sourcepub fn is_built_in_resource(
&self,
resource: impl AsRef<UntypedResource>,
) -> bool
pub fn is_built_in_resource( &self, resource: impl AsRef<UntypedResource>, ) -> bool
Checks whether the given resource is a built-in resource instance or not.