pub struct DataSource {
pub extension: Cow<'static, str>,
pub bytes: Cow<'static, [u8]>,
}Expand description
Data source of a built-in resource.
Fields
extension: Cow<'static, str>File extension, associated with the data source.
bytes: Cow<'static, [u8]>The actual data.
Implementations
Sourceimpl DataSource
impl DataSource
Sourcepub fn new(path: &'static str, data: &'static [u8]) -> Self
pub fn new(path: &'static str, data: &'static [u8]) -> Self
Creates a new data source with the given path and the data. The data must be embedded in
the application binary using include_bytes macro or similar. Use crate::embedded_data_source
macro to combine a call to this method with include_bytes macro.