ResourceConstructorContainer

Struct ResourceConstructorContainer 

pub struct ResourceConstructorContainer {
    pub map: Mutex<FxHashMap<Uuid, ResourceDataConstructor>>,
}
A special container that is able to create resources by their type UUID.

Fields

map: Mutex<FxHashMap<Uuid, ResourceDataConstructor>>

Map of Type UUID -> Constructor

Implementations

Source

impl ResourceConstructorContainer

pub fn new() -> Self

Creates default resource data constructor container.

pub fn add<T>(&self)

Adds new type constructor for a given type and return previous constructor for the type (if any).

pub fn add_custom(&self, type_uuid: Uuid, constructor: ResourceDataConstructor)

Adds custom type constructor.

pub fn remove(&self, type_uuid: Uuid)

Unregisters type constructor.

pub fn try_create(&self, type_uuid: &Uuid) -> Option<Box<dyn ResourceData>>

Makes an attempt to create a resource data using provided type UUID. It may fail if there is no resource data constructor for specified type UUID.

pub fn len(&self) -> usize

Returns total amount of constructors.

pub fn is_empty(&self) -> bool

Returns true if the container is empty.