pub struct ResourceDataConstructor {
pub type_name: String,
pub callback: Box<dyn FnMut() -> Box<dyn ResourceData> + Send>,
}Expand description
A simple type alias for boxed resource constructor.
Fields
type_name: StringType name of the resource, produced by this constructor.
callback: Box<dyn FnMut() -> Box<dyn ResourceData> + Send>Boxed callback, that is able to produce a resource in the default state.
Implementations
Sourceimpl ResourceDataConstructor
impl ResourceDataConstructor
Sourcepub fn create_instance(&mut self) -> Box<dyn ResourceData>
pub fn create_instance(&mut self) -> Box<dyn ResourceData>
Creates a new resource instance in the default state.