pub struct ResourceEventBroadcaster { /* private fields */ }Expand description
Event broadcaster is responsible for delivering resource events to “subscribers”.
Implementations
Sourceimpl ResourceEventBroadcaster
impl ResourceEventBroadcaster
Sourcepub fn add(&self, sender: ResourceEventSender) -> Handle<ResourceEventSender>
pub fn add(&self, sender: ResourceEventSender) -> Handle<ResourceEventSender>
Adds an event sender to the broadcaster and returns its handle.
Sourcepub fn remove(&self, handle: Handle<ResourceEventSender>) -> ResourceEventSender
pub fn remove(&self, handle: Handle<ResourceEventSender>) -> ResourceEventSender
Removes an event sender by its handle.
Sourcepub fn broadcast(&self, event: ResourceEvent)
pub fn broadcast(&self, event: ResourceEvent)
Sends an event to all “subscribers” in the broadcaster.
Sourcepub fn broadcast_loaded(&self, resource: UntypedResource)
pub fn broadcast_loaded(&self, resource: UntypedResource)
Sends a ResourceEvent::Loaded event to all “subscribers” in the broadcaster.
Sourcepub fn broadcast_loaded_or_reloaded(
&self,
resource: UntypedResource,
reload: bool,
)
pub fn broadcast_loaded_or_reloaded( &self, resource: UntypedResource, reload: bool, )
Sends either a ResourceEvent::Loaded event or a ResourceEvent::Reloaded to all
“subscribers” in the broadcaster depending on the reload parameter.