pub struct ResourceDependencyGraph {
pub root: ResourceGraphNode,
}Expand description
Resource dependency graph allows you to collect all dependencies of a resource in structured form. Internally, it uses reflection to look into resources content and find dependent resources. An example of dependent resource is very simple: if you have a 3D model, then it most likely has a bunch of textures - these textures are dependent resources. A more complex example - a game level could depend on lots of prefabs, which in their turn may depend on other prefabs, textures, sounds, etc.
Fields
root: ResourceGraphNodeRoot node of the graph.
Implementations
Sourceimpl ResourceDependencyGraph
impl ResourceDependencyGraph
Sourcepub fn new(resource: &UntypedResource) -> Self
pub fn new(resource: &UntypedResource) -> Self
Creates a new resource dependency graph starting from a given untyped resource.
Sourcepub fn for_each<F: FnMut(&UntypedResource)>(&self, func: F)
pub fn for_each<F: FnMut(&UntypedResource)>(&self, func: F)
Iterates over each dependency graph node and applying the specific function to them.
Sourcepub fn pretty_print(&self) -> String
pub fn pretty_print(&self) -> String
Prints the entire dependency graph into a string.