pub enum FolderMovementError {
Io(Error),
FileError(FileError),
ResourceMovementError(ResourceMovementError),
NotInRegistry {
dest_dir: PathBuf,
},
HierarchyError {
src_dir: PathBuf,
dest_dir: PathBuf,
},
}Expand description
A set of potential errors that may occur when moving a folder with resources.
Variants
Io(Error)
An IO error.
FileError(FileError)
A file error.
ResourceMovementError(ResourceMovementError)
NotInRegistry
The folder is not in the registry.
HierarchyError
Trying to move a folder into one of its own sub-folders.