ResourceMovementError

Enum ResourceMovementError 

pub enum ResourceMovementError {
    Io(Error),
    FileError(FileError),
    AlreadyExist {
        src_path: PathBuf,
        dest_path: PathBuf,
    },
    DestinationPathIsInvalid {
        src_path: PathBuf,
        dest_path: PathBuf,
    },
    ResourceRegistryLocationUnknown {
        resource_path: PathBuf,
    },
    NotInRegistry {
        resource_path: PathBuf,
    },
    OutsideOfRegistry {
        absolute_src_path: PathBuf,
        absolute_dest_dir: PathBuf,
        absolute_registry_dir: PathBuf,
    },
    NoPath(UntypedResource),
}
A possible set of errors that may occur during resource movement.

Variants



Io(Error)

An IO error.



FileError(FileError)

A file error.



AlreadyExist

The resource at the src_path already exist at the dest_path.

Fields

src_path: PathBuf

Source path of the resource.

dest_path: PathBuf

The path at which a resource with the same name is located.



DestinationPathIsInvalid

The new path for a resource is invalid.

Fields

src_path: PathBuf

Source path of the resource.

dest_path: PathBuf

The invalid destination path.



ResourceRegistryLocationUnknown

Resource registry location is unknown (the registry wasn’t saved yet).

Fields

resource_path: PathBuf

A path of the resource being moved.



NotInRegistry

The resource is not in the registry.

Fields

resource_path: PathBuf

A path of the resource being moved.



OutsideOfRegistry

Attempting to move a resource outside the registry.

Fields

absolute_src_path: PathBuf

An absolute path of the resource being moved.

absolute_dest_dir: PathBuf

An absolute path of the destination folder.

absolute_registry_dir: PathBuf

An absolute path of the resource registry.



NoPath(UntypedResource)

A resource has no path. It is either an embedded resource or in an invalid state (failed to load or still loading).