ResourceMetadata

Struct ResourceMetadata 

pub struct ResourceMetadata {
    pub resource_id: Uuid,
}
Resource metadata contains additional information that cannot be stored in the resource file itself. The most important bit of information is a resource uuid, this id is used to as reference that does not change when the resource moved or renamed.

Fields

resource_id: Uuid

A resource uuid, this id is used to as reference that does not change when the resource moved or renamed.

Implementations

Source

impl ResourceMetadata

pub const EXTENSION: &'static str = "meta"

Standard extension of a metadata file.

pub fn new_with_random_id() -> Self

Creates a new metadata with random uuid.

pub async fn load_from_file_async( path: &Path, resource_io: &dyn ResourceIo, ) -> Result<Self, FileError>

Tries to load a metadata from the given path.

pub async fn save_async( &self, path: &Path, resource_io: &dyn ResourceIo, ) -> Result<(), FileError>

Tries to write the metadata to the given path. This method is meant to be used in async context. For sync version use Self::save_sync.

pub fn save_sync( &self, path: &Path, resource_io: &dyn ResourceIo, ) -> Result<(), FileError>

Tries to write the metadata to the given path.