pub struct RegistryUpdate<T> {
pub changed: bool,
pub value: T,
}Expand description
A value returned from an update operation to a ResourceRegistryRefMut,
including a flag that indicates whether the operation changed the registry.
Fields
changed: boolTrue if the registry was changed.
value: TThe value produced by the operation.