ResourceRegistryRefMut

Struct ResourceRegistryRefMut 

pub struct ResourceRegistryRefMut<'a> { /* private fields */ }
A mutable reference to a resource registry. Automatically saves the registry back to a source from which it was loaded when an instance of this object is dropped. To prevent saving use std::mem::forget after you’ve finished working with the mutable reference.

Implementations

Source

impl ResourceRegistryRefMut<'_>

pub fn read_metadata( &mut self, path: PathBuf, ) -> Result<RegistryUpdate<ResourceMetadata>, FileError>

Read the metadata from the file at the given path.

pub fn write_metadata( &mut self, uuid: Uuid, path: PathBuf, ) -> Result<RegistryUpdate<Option<PathBuf>>, FileError>

Writes the new metadata file for a resource at the given path and registers the resource in the registry.

pub fn remove_metadata( &mut self, path: impl AsRef<Path>, ) -> Result<(), FileError>

Unregisters the resource at the given path (if any) from the registry and deletes its associated metadata file.

pub fn register( &mut self, uuid: Uuid, path: PathBuf, ) -> RegistryUpdate<Option<PathBuf>>

Registers a new pair UUID -> Path, and returns the former path for this UUID.

pub fn unregister(&mut self, uuid: Uuid) -> Option<PathBuf>

Unregisters a resource path with the given UUID, and returns the former path for the Uuid, if it was registered.

pub fn unregister_path(&mut self, path: impl AsRef<Path>) -> Option<Uuid>

Unregisters a resource path, and returns the UUID if the given path was previously registered.

pub fn set_container(&mut self, registry_container: RegistryContainer)

Completely replaces the internal storage.