Resource

Struct Resource 

pub struct Resource<T: Debug> { /* private fields */ }
A resource of particular data type. It is a typed wrapper around UntypedResource which does type checks at runtime. See UntypedResource for more info.

Default State

Default state of the resource will be ResourceState::Ok with T::default.

Implementations

Source

impl<T: Debug> Resource<T>

pub const UNTYPED: &'static str = "untyped"

Source

impl<T> Resource<T>

pub fn summary(&self) -> String

Create a summary of this resource handle, wht UUID, embedded/external, and Ok, Pending, Error, etc.

pub fn new_pending(uuid: Uuid, kind: ResourceKind) -> Self

Creates new resource in pending state.

pub fn new_ok(resource_uuid: Uuid, kind: ResourceKind, data: T) -> Self

Creates new resource in ok state (fully loaded).

pub fn new_embedded(data: T) -> Self

Creates a new embedded resource in ok state (fully loaded).

pub fn new_load_error( kind: ResourceKind, path: PathBuf, error: LoadError, ) -> Self

Creates new resource in error state.

pub fn into_untyped(self) -> UntypedResource

Converts self to internal value.

pub fn state(&self) -> ResourceHeaderGuard<'_, T>

Locks internal mutex provides access to the state.

pub fn try_acquire_state(&self) -> Option<ResourceHeaderGuard<'_, T>>

Tries to lock internal mutex provides access to the state.

pub fn header(&self) -> MutexGuard<'_, ResourceHeader>

Locks the resource and provides access to its header. See ResourceHeader docs for more info.

pub fn is_loading(&self) -> bool

Returns true if the resource is still loading.

pub fn is_ok(&self) -> bool

Returns true if the resource is fully loaded and ready for use.

pub fn is_failed_to_load(&self) -> bool

Returns true if the resource is failed to load.

pub fn use_count(&self) -> usize

Returns exact amount of users of the resource.

pub fn key(&self) -> u64

Returns a pointer as numeric value which can be used as a hash.

pub fn kind(&self) -> ResourceKind

Returns kind of the resource, if the resource is registered.

pub fn resource_uuid(&self) -> Uuid

The UUID of the resource. All resources must have a UUID, even if they are not loaded because the UUID is how the resource manager knows the path to load from.

pub fn set_path(&mut self, new_kind: ResourceKind)

Sets a new kind of the resource.

pub fn data_ref(&self) -> ResourceDataRef<'_, T>

Allows you to get a reference to the resource data. The returned object implements Deref and DerefMut traits, and basically acts like a reference to the resource value.

Panic

An attempt to dereference the returned object will result in panic if the resource is not loaded yet, or there was a loading error. Usually this is ok because you should chain this call like this resource.await?.data_ref(). Every resource implements Future trait, and it returns Result, so if you’ll await the future then you’ll get Result, so call to data_ref will be fine.

You can also use [ResourceDataRef::as_loaded_ref] and [ResourceDataRef::as_loaded_mut] methods that perform checked access to the resource internals.

pub fn save(&self, path: &Path) -> Result<(), Box<dyn Error>>

Tries to save the resource to the specified path.