ResourceHeaderGuard

Struct ResourceHeaderGuard 

pub struct ResourceHeaderGuard<'a, T>{ /* private fields */ }
Provides typed access to a resource state.

Implementations

Source

impl<T> ResourceHeaderGuard<'_, T>

pub fn resource_uuid(&self) -> Uuid

The UUID that universally identifies the resource.

pub fn kind(&self) -> ResourceKind

Returns resource kind of the locked resource.

pub fn data(&mut self) -> Option<&mut T>

Tries to fetch the underlying data of the resource type. This operation will fail if the locked resource is not in ResourceState::Ok or if its actual data does not match the type of the resource.

pub fn data_ref(&self) -> Option<&T>

Tries to fetch the underlying data of the resource type. This operation will fail if the locked resource is not in ResourceState::Ok or if its actual data does not match the type of the resource.

pub fn data_ref_with_id(&self) -> Option<(&T, &Uuid)>

Tries to fetch the underlying data of the resource type. This operation will fail if the locked resource is not in ResourceState::Ok or if its actual data does not match the type of the resource.