pub struct ResourceLoadersContainer { /* private fields */ }Expand description
Container for resource loaders.
Implementations
Sourceimpl ResourceLoadersContainer
impl ResourceLoadersContainer
Sourcepub fn set<T>(&mut self, loader: T) -> Option<T>where
T: ResourceLoader,
pub fn set<T>(&mut self, loader: T) -> Option<T>where
T: ResourceLoader,
Adds new resource loader or replaces existing. There could be only one loader of a given type at the same time. You can use this method to replace resource loaders with your own loaders.
Sourcepub fn try_replace<Prev, New>(&mut self, new_loader: New) -> Option<Prev>where
Prev: ResourceLoader,
New: ResourceLoader,
pub fn try_replace<Prev, New>(&mut self, new_loader: New) -> Option<Prev>where
Prev: ResourceLoader,
New: ResourceLoader,
Searches for an instance of a resource loader of type Prev and replaces it with an other instance
of a type New.
Sourcepub fn find<T>(&self) -> Option<&T>where
T: ResourceLoader,
pub fn find<T>(&self) -> Option<&T>where
T: ResourceLoader,
Tries to find an instance of a resource loader of the given type `T.
Sourcepub fn find_mut<T>(&mut self) -> Option<&mut T>where
T: ResourceLoader,
pub fn find_mut<T>(&mut self) -> Option<&mut T>where
T: ResourceLoader,
Tries to find an instance of a resource loader of the given type `T.
Sourcepub fn iter(&self) -> impl Iterator<Item = &dyn ResourceLoader>
pub fn iter(&self) -> impl Iterator<Item = &dyn ResourceLoader>
Returns an iterator yielding shared references to “untyped” resource loaders.
Sourcepub fn iter_mut(&mut self) -> impl Iterator<Item = &mut dyn ResourceLoader>
pub fn iter_mut(&mut self) -> impl Iterator<Item = &mut dyn ResourceLoader>
Returns an iterator yielding mutable references to “untyped” resource loaders.
Sourcepub fn is_supported_resource(&self, path: &Path) -> bool
pub fn is_supported_resource(&self, path: &Path) -> bool
Returns true if there’s at least one resource loader, that supports the extension of the
file at the given path.
Sourcepub fn loader_for_data_type(
&self,
data_type_uuid: Uuid,
) -> Option<&dyn ResourceLoader>
pub fn loader_for_data_type( &self, data_type_uuid: Uuid, ) -> Option<&dyn ResourceLoader>
Tries to fina a loader for the specified data type uuid.
Sourcepub fn is_extension_matches_type<T>(&self, path: &Path) -> boolwhere
T: TypedResourceData,
pub fn is_extension_matches_type<T>(&self, path: &Path) -> boolwhere
T: TypedResourceData,
Checks if there’s a resource loader for the given path and the data type produced by the
loader matches the given type T.
Sourcepub fn loader_for(&self, path: &Path) -> Option<&dyn ResourceLoader>
pub fn loader_for(&self, path: &Path) -> Option<&dyn ResourceLoader>
Checks if there’s a loader for the given path.