pub enum ResourceMovementError {
Io(Error),
FileError(FileError),
AlreadyExist {
src_path: PathBuf,
dest_path: PathBuf,
},
DestinationPathIsInvalid {
src_path: PathBuf,
dest_path: PathBuf,
},
ResourceRegistryLocationUnknown {
resource_path: PathBuf,
},
NotInRegistry {
resource_path: PathBuf,
},
OutsideOfRegistry {
absolute_src_path: PathBuf,
absolute_dest_dir: PathBuf,
absolute_registry_dir: PathBuf,
},
NoPath(UntypedResource),
}Expand description
A possible set of errors that may occur during resource movement.
Variants
Io(Error)
An IO error.
FileError(FileError)
A file error.
AlreadyExist
The resource at the src_path already exist at the dest_path.
Fields
DestinationPathIsInvalid
The new path for a resource is invalid.
Fields
ResourceRegistryLocationUnknown
Resource registry location is unknown (the registry wasn’t saved yet).
NotInRegistry
The resource is not in the registry.
OutsideOfRegistry
Attempting to move a resource outside the registry.
Fields
NoPath(UntypedResource)
A resource has no path. It is either an embedded resource or in an invalid state (failed to load or still loading).