pub struct ResourceMetadata {
pub resource_id: Uuid,
}Expand description
Resource metadata contains additional information that cannot be stored in the resource file itself. The most important bit of information is a resource uuid, this id is used to as reference that does not change when the resource moved or renamed.
Fields
resource_id: UuidA resource uuid, this id is used to as reference that does not change when the resource moved or renamed.
Implementations
Sourceimpl ResourceMetadata
impl ResourceMetadata
Sourcepub fn new_with_random_id() -> Self
pub fn new_with_random_id() -> Self
Creates a new metadata with random uuid.
Sourcepub async fn load_from_file_async(
path: &Path,
resource_io: &dyn ResourceIo,
) -> Result<Self, FileError>
pub async fn load_from_file_async( path: &Path, resource_io: &dyn ResourceIo, ) -> Result<Self, FileError>
Tries to load a metadata from the given path.
Sourcepub async fn save_async(
&self,
path: &Path,
resource_io: &dyn ResourceIo,
) -> Result<(), FileError>
pub async fn save_async( &self, path: &Path, resource_io: &dyn ResourceIo, ) -> Result<(), FileError>
Tries to write the metadata to the given path. This method is meant to be used in async
context. For sync version use Self::save_sync.